# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class BuyNowDayAheadOfferSortBy(str, Enum):
    """
    BuyNowDayAheadOfferSortBy
    """

    """
    allowed enum values
    """
    CAPACITY_ASC = 'CAPACITY_ASC'
    CAPACITY_DESC = 'CAPACITY_DESC'
    MOST_MTU_OFFERED_ASC = 'MOST_MTU_OFFERED_ASC'
    MOST_MTU_OFFERED_DESC = 'MOST_MTU_OFFERED_DESC'
    PRICE_ASC = 'PRICE_ASC'
    PRICE_DESC = 'PRICE_DESC'
    TIME_LEFT_ASC = 'TIME_LEFT_ASC'
    TIME_LEFT_DESC = 'TIME_LEFT_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> BuyNowDayAheadOfferSortBy:
        """Create an instance of BuyNowDayAheadOfferSortBy from a JSON string"""
        return BuyNowDayAheadOfferSortBy(json.loads(json_str))


