# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid import DayAheadOrIntraDayDefaultBid  # noqa: E501

class TestDayAheadOrIntraDayDefaultBid(unittest.TestCase):
    """DayAheadOrIntraDayDefaultBid unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayDefaultBid:
        """Test DayAheadOrIntraDayDefaultBid
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayDefaultBid`
        """
        model = DayAheadOrIntraDayDefaultBid()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayDefaultBid(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                delivery_period_start = '2022-01-04T10:00Z',
                delivery_period_end = '2022-01-04T11:00Z',
                validity_period_start = '2022-01-04T00:00Z',
                validity_period_end = '2022-01-04T00:00Z',
                mtu_size = 'MTU_15_MINS',
                bids = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids.DayAheadOrIntraDayDefaultBid_bids(
                        mtus = [
                            empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids_mtus.DayAheadOrIntraDayDefaultBid_bids_mtus(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ]
            )
        else:
            return DayAheadOrIntraDayDefaultBid(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                delivery_period_start = '2022-01-04T10:00Z',
                validity_period_start = '2022-01-04T00:00Z',
                mtu_size = 'MTU_15_MINS',
                bids = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids.DayAheadOrIntraDayDefaultBid_bids(
                        mtus = [
                            empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid_bids_mtus.DayAheadOrIntraDayDefaultBid_bids_mtus(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ],
        )
        """

    def testDayAheadOrIntraDayDefaultBid(self):
        """Test DayAheadOrIntraDayDefaultBid"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
