# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuctionIntraDayProductType(str, Enum):
    """
    AuctionIntraDayProductType
    """

    """
    allowed enum values
    """
    ID_EXPLICIT_ID_1 = 'ID_EXPLICIT_ID_1'
    ID_EXPLICIT_ID_2 = 'ID_EXPLICIT_ID_2'
    ID_EXPLICIT_ID_3 = 'ID_EXPLICIT_ID_3'
    ID_EXPLICIT_ID_4 = 'ID_EXPLICIT_ID_4'

    @classmethod
    def from_json(cls, json_str: str) -> AuctionIntraDayProductType:
        """Create an instance of AuctionIntraDayProductType from a JSON string"""
        return AuctionIntraDayProductType(json.loads(json_str))


