# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.organisation_document_api import OrganisationDocumentApi  # noqa: E501


class TestOrganisationDocumentApi(unittest.TestCase):
    """OrganisationDocumentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganisationDocumentApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_create_organisation_document(self) -> None:
        """Test case for create_organisation_document

        """
        pass

    def test_delete_organisation_document(self) -> None:
        """Test case for delete_organisation_document

        """
        pass

    def test_get_organisation_document_options(self) -> None:
        """Test case for get_organisation_document_options

        """
        pass

    def test_get_organisation_documents(self) -> None:
        """Test case for get_organisation_documents

        """
        pass


if __name__ == '__main__':
    unittest.main()
