# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.settlement_per_source import SettlementPerSource  # noqa: E501

class TestSettlementPerSource(unittest.TestCase):
    """SettlementPerSource unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SettlementPerSource:
        """Test SettlementPerSource
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SettlementPerSource`
        """
        model = SettlementPerSource()  # noqa: E501
        if include_optional:
            return SettlementPerSource(
                source = 'AUCTION',
                sub_source = 'EXPLICIT_AUCTION_MULTI_ANNUAL',
                total_amount = 1.337,
                values = [
                    empire_platform_api_public_client.models.settlement_item.SettlementItem(
                        direction = 'GB_NL', 
                        transmission_rights = 56, 
                        amount = 1.337, )
                    ]
            )
        else:
            return SettlementPerSource(
                source = 'AUCTION',
                sub_source = 'EXPLICIT_AUCTION_MULTI_ANNUAL',
                total_amount = 1.337,
                values = [
                    empire_platform_api_public_client.models.settlement_item.SettlementItem(
                        direction = 'GB_NL', 
                        transmission_rights = 56, 
                        amount = 1.337, )
                    ],
        )
        """

    def testSettlementPerSource(self):
        """Test SettlementPerSource"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
