# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results import DayAheadOrIntraDayAuctionResults  # noqa: E501

class TestDayAheadOrIntraDayAuctionResults(unittest.TestCase):
    """DayAheadOrIntraDayAuctionResults unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DayAheadOrIntraDayAuctionResults:
        """Test DayAheadOrIntraDayAuctionResults
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DayAheadOrIntraDayAuctionResults`
        """
        model = DayAheadOrIntraDayAuctionResults()  # noqa: E501
        if include_optional:
            return DayAheadOrIntraDayAuctionResults(
                congestion_rent = empire_platform_api_public_client.models.auction_result_congestion_rent.AuctionResultCongestionRent(
                    oc_revenue = 1.337, 
                    returns_revenue = 1.337, 
                    total_revenue = 1.337, ),
                mtus = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results_mtu.DayAheadOrIntraDayAuctionResultsMtu(
                        mtu = '2022-01-04T10:00Z', 
                        requested_capacity = 56, 
                        allocated_trs = 56, 
                        marginal_price = 1.337, 
                        participant_count = 0, 
                        successful_participant_count = 0, 
                        bid_count = 0, )
                    ],
                successful_participants = [
                    empire_platform_api_public_client.models.auction_result_participant.AuctionResultParticipant(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', 
                        eic_code = '---7S--058SL--92', )
                    ]
            )
        else:
            return DayAheadOrIntraDayAuctionResults(
                mtus = [
                    empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results_mtu.DayAheadOrIntraDayAuctionResultsMtu(
                        mtu = '2022-01-04T10:00Z', 
                        requested_capacity = 56, 
                        allocated_trs = 56, 
                        marginal_price = 1.337, 
                        participant_count = 0, 
                        successful_participant_count = 0, 
                        bid_count = 0, )
                    ],
                successful_participants = [
                    empire_platform_api_public_client.models.auction_result_participant.AuctionResultParticipant(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        name = '', 
                        eic_code = '---7S--058SL--92', )
                    ],
        )
        """

    def testDayAheadOrIntraDayAuctionResults(self):
        """Test DayAheadOrIntraDayAuctionResults"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
