# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 3.0.8
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data import ParticipantDashboardNettedNominationsData  # noqa: E501

class TestParticipantDashboardNettedNominationsData(unittest.TestCase):
    """ParticipantDashboardNettedNominationsData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParticipantDashboardNettedNominationsData:
        """Test ParticipantDashboardNettedNominationsData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardNettedNominationsData`
        """
        model = ParticipantDashboardNettedNominationsData()  # noqa: E501
        if include_optional:
            return ParticipantDashboardNettedNominationsData(
                mtu_size = 'MTU_15_MINS',
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus.ParticipantDashboardNettedNominationsData_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        aggregated_nominations = [
                            empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_aggregated_nominations.ParticipantDashboardNettedNominationsData_mtus_aggregatedNominations(
                                direction = 'GB_NL', 
                                value = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_netted_nominations.ParticipantDashboardNettedNominationsData_mtus_nettedNominations(
                            flow = 56, 
                            direction = 'GB_NL', ), )
                    ]
            )
        else:
            return ParticipantDashboardNettedNominationsData(
                mtu_size = 'MTU_15_MINS',
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus.ParticipantDashboardNettedNominationsData_mtus(
                        mtu = '2022-01-04T10:00Z', 
                        aggregated_nominations = [
                            empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_aggregated_nominations.ParticipantDashboardNettedNominationsData_mtus_aggregatedNominations(
                                direction = 'GB_NL', 
                                value = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_netted_nominations.ParticipantDashboardNettedNominationsData_mtus_nettedNominations(
                            flow = 56, 
                            direction = 'GB_NL', ), )
                    ],
        )
        """

    def testParticipantDashboardNettedNominationsData(self):
        """Test ParticipantDashboardNettedNominationsData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
